@@ -12,7 +12,7 @@ def request_accesstoken(acc: str, pwd: str) -> str:
     response = requests.get(url, data)
     if response.status_code == 200:
         # print(response.json())
-        accessToken = response.json().get("accessToken")
+        accessToken = response.json().get("token")
         return accessToken
 
 
@@ -21,24 +21,32 @@ class base:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, data={}, method="GET", url=None):
+    def request(self, api_name=None, params={}, data={}, method="GET", url=None, json={}):
         host_name = "http://bms.microc.cn/shopguide/api/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
         if not url:
             if host_name not in api_name:
                 url = f"{host_name}{api_name}"
 
-        if "accessToken" not in data:
+        if "accessToken" not in params:
             # 没有token自动添加
-            data["accessToken"] = self.token
-        if "appSecret" not in data:
+            params["accessToken"] = self.token
+        if "appSecret" not in params:
             # 没有token自动添加
-            data["appSecret"] = self.app_secret
+            params["appSecret"] = self.app_secret
 
         if method == "GET":
-            response = requests.get(url, params=data)
+            params.update(data)
+            response = requests.get(url, params=params)
         elif method == "POST":
-            response = requests.post(url, data=data)
+            # print(method, data, json)
+            if data:
+                response = requests.post(url, params=params, data=data)
+            elif json:
+                response = requests.post(url, params=params, json=json)
+            else:
+                raise ValueError("网络请求数据格式错误。")
+
         else:
             raise ValueError("请求方法错误。")
         # print(url, response.status_code)
